Common messages
===============

.. currentmodule:: jeepney

These classes are *message generators*. Wrap them in a :ref:`Proxy
<msggen_proxies>` class to actually send the messages as well.

.. autoclass:: Properties
   :members:

.. autoclass:: Introspectable
   :members:



.. autoclass:: DBus
   :members:
   :undoc-members:

   There is a ready-made instance of this at ``jeepney.message_bus``.

.. autoclass:: Monitoring
   :members:
